@@ -78,7 +78,9 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&amd64_fam15h_interlagos_support,
 	&amd64_fam15h_nb_support,
 	&amd64_fam16h_support,
-	&amd64_fam17h_support,
+	&amd64_fam17h_deprecated_support,
+	&amd64_fam17h_zen1_support,
+	&amd64_fam17h_zen2_support,
 	&intel_core_support,
 	&intel_atom_support,
 	&intel_nhm_support,
@@ -105,6 +107,8 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&intel_bdw_ep_support,
 	&intel_skl_support,
 	&intel_skx_support,
+	&intel_clx_support,
+	&intel_icl_support,
 	&intel_rapl_support,
 	&intel_snbep_unc_cb0_support,
 	&intel_snbep_unc_cb1_support,
@@ -129,6 +133,7 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&intel_knc_support,
 	&intel_slm_support,
 	&intel_glm_support,
+	&intel_tmt_support,
 	&intel_ivbep_unc_cb0_support,
 	&intel_ivbep_unc_cb1_support,
 	&intel_ivbep_unc_cb2_support,
@@ -317,6 +322,121 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&intel_bdx_unc_r3qpi0_support,
 	&intel_bdx_unc_r3qpi1_support,
 	&intel_bdx_unc_r3qpi2_support,
+	&intel_skx_unc_cha0_support,
+	&intel_skx_unc_cha1_support,
+	&intel_skx_unc_cha2_support,
+	&intel_skx_unc_cha3_support,
+	&intel_skx_unc_cha4_support,
+	&intel_skx_unc_cha5_support,
+	&intel_skx_unc_cha6_support,
+	&intel_skx_unc_cha7_support,
+	&intel_skx_unc_cha8_support,
+	&intel_skx_unc_cha9_support,
+	&intel_skx_unc_cha10_support,
+	&intel_skx_unc_cha11_support,
+	&intel_skx_unc_cha12_support,
+	&intel_skx_unc_cha13_support,
+	&intel_skx_unc_cha14_support,
+	&intel_skx_unc_cha15_support,
+	&intel_skx_unc_cha16_support,
+	&intel_skx_unc_cha17_support,
+	&intel_skx_unc_cha18_support,
+	&intel_skx_unc_cha19_support,
+	&intel_skx_unc_cha20_support,
+	&intel_skx_unc_cha21_support,
+	&intel_skx_unc_cha22_support,
+	&intel_skx_unc_cha23_support,
+	&intel_skx_unc_cha24_support,
+	&intel_skx_unc_cha25_support,
+	&intel_skx_unc_cha26_support,
+	&intel_skx_unc_cha27_support,
+	&intel_skx_unc_iio0_support,
+	&intel_skx_unc_iio1_support,
+	&intel_skx_unc_iio2_support,
+	&intel_skx_unc_iio3_support,
+	&intel_skx_unc_iio4_support,
+	&intel_skx_unc_iio5_support,
+	&intel_skx_unc_imc0_support,
+	&intel_skx_unc_imc1_support,
+	&intel_skx_unc_imc2_support,
+	&intel_skx_unc_imc3_support,
+	&intel_skx_unc_imc4_support,
+	&intel_skx_unc_imc5_support,
+	&intel_skx_unc_pcu_support,
+	&intel_skx_unc_upi0_support,
+	&intel_skx_unc_upi1_support,
+	&intel_skx_unc_upi2_support,
+	&intel_skx_unc_m2m0_support,
+	&intel_skx_unc_m2m1_support,
+	&intel_skx_unc_ubo_support,
+	&intel_skx_unc_m3upi0_support,
+	&intel_skx_unc_m3upi1_support,
+	&intel_skx_unc_m3upi2_support,
+	&intel_skx_unc_irp_support,
+	&intel_knm_support,
+	&intel_knm_unc_imc0_support,
+	&intel_knm_unc_imc1_support,
+	&intel_knm_unc_imc2_support,
+	&intel_knm_unc_imc3_support,
+	&intel_knm_unc_imc4_support,
+	&intel_knm_unc_imc5_support,
+	&intel_knm_unc_imc_uclk0_support,
+	&intel_knm_unc_imc_uclk1_support,
+	&intel_knm_unc_edc_uclk0_support,
+	&intel_knm_unc_edc_uclk1_support,
+	&intel_knm_unc_edc_uclk2_support,
+	&intel_knm_unc_edc_uclk3_support,
+	&intel_knm_unc_edc_uclk4_support,
+	&intel_knm_unc_edc_uclk5_support,
+	&intel_knm_unc_edc_uclk6_support,
+	&intel_knm_unc_edc_uclk7_support,
+	&intel_knm_unc_edc_eclk0_support,
+	&intel_knm_unc_edc_eclk1_support,
+	&intel_knm_unc_edc_eclk2_support,
+	&intel_knm_unc_edc_eclk3_support,
+	&intel_knm_unc_edc_eclk4_support,
+	&intel_knm_unc_edc_eclk5_support,
+	&intel_knm_unc_edc_eclk6_support,
+	&intel_knm_unc_edc_eclk7_support,
+	&intel_knm_unc_cha0_support,
+	&intel_knm_unc_cha1_support,
+	&intel_knm_unc_cha2_support,
+	&intel_knm_unc_cha3_support,
+	&intel_knm_unc_cha4_support,
+	&intel_knm_unc_cha5_support,
+	&intel_knm_unc_cha6_support,
+	&intel_knm_unc_cha7_support,
+	&intel_knm_unc_cha8_support,
+	&intel_knm_unc_cha9_support,
+	&intel_knm_unc_cha10_support,
+	&intel_knm_unc_cha11_support,
+	&intel_knm_unc_cha12_support,
+	&intel_knm_unc_cha13_support,
+	&intel_knm_unc_cha14_support,
+	&intel_knm_unc_cha15_support,
+	&intel_knm_unc_cha16_support,
+	&intel_knm_unc_cha17_support,
+	&intel_knm_unc_cha18_support,
+	&intel_knm_unc_cha19_support,
+	&intel_knm_unc_cha20_support,
+	&intel_knm_unc_cha21_support,
+	&intel_knm_unc_cha22_support,
+	&intel_knm_unc_cha23_support,
+	&intel_knm_unc_cha24_support,
+	&intel_knm_unc_cha25_support,
+	&intel_knm_unc_cha26_support,
+	&intel_knm_unc_cha27_support,
+	&intel_knm_unc_cha28_support,
+	&intel_knm_unc_cha29_support,
+	&intel_knm_unc_cha30_support,
+	&intel_knm_unc_cha31_support,
+	&intel_knm_unc_cha32_support,
+	&intel_knm_unc_cha33_support,
+	&intel_knm_unc_cha34_support,
+	&intel_knm_unc_cha35_support,
+	&intel_knm_unc_cha36_support,
+	&intel_knm_unc_cha37_support,
+	&intel_knm_unc_m2pcie_support,
 	&intel_x86_arch_support, /* must always be last for x86 */
 #endif
 
@@ -367,11 +487,25 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&arm_cortex_a57_support,
 	&arm_cortex_a53_support,
 	&arm_xgene_support,
+	&arm_thunderx2_support,
+	&arm_thunderx2_dmc0_support,
+	&arm_thunderx2_dmc1_support,
+	&arm_thunderx2_llc0_support,
+	&arm_thunderx2_llc1_support,
+	&arm_thunderx2_ccpi0_support,
+	&arm_thunderx2_ccpi1_support,
 #endif
 #ifdef CONFIG_PFMLIB_ARCH_ARM64
 	&arm_cortex_a57_support,
 	&arm_cortex_a53_support,
 	&arm_xgene_support,
+	&arm_thunderx2_support,
+	&arm_thunderx2_dmc0_support,
+	&arm_thunderx2_dmc1_support,
+	&arm_thunderx2_llc0_support,
+	&arm_thunderx2_llc1_support,
+	&arm_thunderx2_ccpi0_support,
+	&arm_thunderx2_ccpi1_support,
 #endif
 
 #ifdef CONFIG_PFMLIB_ARCH_S390X
@@ -582,6 +716,12 @@ pfmlib_pmu_active(pfmlib_pmu_t *pmu)
         return !!(pmu->flags & PFMLIB_PMU_FL_ACTIVE);
 }
 
+static inline int
+pfmlib_pmu_deprecated(pfmlib_pmu_t *pmu)
+{
+        return !!(pmu->flags & PFMLIB_PMU_FL_DEPR);
+}
+
 static inline int
 pfmlib_pmu_initialized(pfmlib_pmu_t *pmu)
 {
@@ -591,7 +731,7 @@ pfmlib_pmu_initialized(pfmlib_pmu_t *pmu)
 static inline pfm_pmu_t
 idx2pmu(int idx)
 {
-	return (pfm_pmu_t)(idx >> PFMLIB_PMU_SHIFT) & PFMLIB_PMU_MASK;
+	return (pfm_pmu_t)((idx >> PFMLIB_PMU_SHIFT) & PFMLIB_PMU_MASK);
 }
 
 static inline pfmlib_pmu_t *
@@ -770,7 +910,7 @@ pfmlib_pmu_activate(pfmlib_pmu_t *p)
 
 	DPRINT("activated %s\n", p->desc);
 
-	return PFM_SUCCESS;	
+	return PFM_SUCCESS;
 }
 
 static inline int
@@ -1214,7 +1354,7 @@ pfmlib_build_event_pattrs(pfmlib_event_desc_t  *e)
 		npattrs++;
 
 	if (npattrs) {
-		e->pattrs = malloc(npattrs * sizeof(*e->pattrs));
+		e->pattrs = calloc(npattrs, sizeof(*e->pattrs));
 		if (!e->pattrs)
 			return PFM_ERR_NOMEM;
 	}
@@ -1365,6 +1505,14 @@ pfmlib_parse_event(const char *event, pfmlib_event_desc_t *d)
 		 */
 		if (!pname && !pfmlib_pmu_active(pmu))
 			continue;
+
+		/*
+		 * if the PMU name is not passed, then if
+		 * the pmu is deprecated, then skip it. It means
+		 * there is a better candidate in the active list
+		 */
+		if (!pname && pfmlib_pmu_deprecated(pmu))
+			continue;
 		/*
 		 * check for requested PMU name,
 		 */
@@ -1832,8 +1980,8 @@ pfm_get_event_info(int idx, pfm_os_t os, pfm_event_info_t *uinfo)
 	/* default data type is uint64 */
 	info.dtype = PFM_DTYPE_UINT64;
 
-	/* reset flags */
-	info.is_precise = 0;
+	/* initialize flags */
+	info.is_speculative = PFM_EVENT_INFO_SPEC_NA;
 
 	ret = pmu->get_event_info(pmu, pidx, &info);
 	if (ret != PFM_SUCCESS)
@@ -1860,10 +2008,10 @@ pfm_get_event_info(int idx, pfm_os_t os, pfm_event_info_t *uinfo)
 int
 pfm_get_event_attr_info(int idx, int attr_idx, pfm_os_t os, pfm_event_attr_info_t *uinfo)
 {
-	pfmlib_event_attr_info_t info;
+	pfmlib_event_attr_info_t *info;
 	pfmlib_event_desc_t e;
 	pfmlib_pmu_t *pmu;
-	size_t sz = sizeof(info);
+	size_t sz = sizeof(*info);
 	int pidx, ret;
 
 	if (!PFMLIB_INITIALIZED())
@@ -1900,10 +2048,7 @@ pfm_get_event_attr_info(int idx, int attr_idx, pfm_os_t os, pfm_event_attr_info_
 	if (attr_idx >= e.npattrs)
 		goto error;
 
-	/*
-	 * copy event_attr_info
-	 */
-	info = e.pattrs[attr_idx];
+	info = &e.pattrs[attr_idx];
 
 	/*
 	 * info.idx = private, namespace specific index,
@@ -1913,18 +2058,20 @@ pfm_get_event_attr_info(int idx, int attr_idx, pfm_os_t os, pfm_event_attr_info_
 	 * cannot memcpy() info into uinfo as they do not
 	 * have the same size, cf. idx field (uint64 vs, uint32)
 	 */
-	uinfo->name  = info.name;
-	uinfo->desc  = info.desc;
-	uinfo->equiv = info.equiv;
+	uinfo->name  = info->name;
+	uinfo->desc  = info->desc;
+	uinfo->equiv = info->equiv;
 	uinfo->size  = sz;
-	uinfo->code  = info.code;
-	uinfo->type  = info.type;
+	uinfo->code  = info->code;
+	uinfo->type  = info->type;
 	uinfo->idx   = attr_idx;
-	uinfo->ctrl  = info.ctrl;
-	uinfo->is_dfl= info.is_dfl;
-	uinfo->is_precise = info.is_precise;
+	uinfo->ctrl  = info->ctrl;
+	uinfo->is_dfl= info->is_dfl;
+	uinfo->is_precise = info->is_precise;
+	uinfo->is_speculative = info->is_speculative;
+	uinfo->support_hw_smpl = info->support_hw_smpl;
 	uinfo->reserved_bits = 0;
-	uinfo->dfl_val64 = info.dfl_val64;
+	uinfo->dfl_val64 = info->dfl_val64;
 
 	ret = PFM_SUCCESS;
 error:
