@@ -64,11 +64,15 @@ typedef struct {
 	uint64_t		code;	/* attribute code */
 	pfm_attr_t		type;	/* attribute type */
 	pfm_attr_ctrl_t		ctrl;	/* what is providing attr */
+
 	uint64_t		idx;	/* attribute opaque index */
+
 	struct {
-		unsigned int    is_dfl:1;	/* is default umask */
-		unsigned int    is_precise:1;	/* Intel X86: supports PEBS */
-		unsigned int	reserved_bits:30;
+		unsigned int    is_dfl:1;	 /* is default umask */
+		unsigned int    is_precise:1;	 /* Intel X86: supports PEBS */
+		unsigned int	is_speculative:2;/* count correct and wrong path occurrences */
+		unsigned int	support_hw_smpl:1;/* can be recorded by hw buffer (Intel X86=EXTPEBS) */
+		unsigned int	reserved_bits:27;
 	};
 	union {
 		uint64_t	dfl_val64;	/* default 64-bit value */
@@ -186,6 +190,8 @@ typedef struct {
 #define PFMLIB_PMU_FL_RAW_UMASK	0x4	/* PMU supports PFM_ATTR_RAW_UMASKS */
 #define PFMLIB_PMU_FL_ARCH_DFL	0x8	/* PMU is arch default */
 #define PFMLIB_PMU_FL_NO_SMPL	0x10	/* PMU does not support sampling */
+#define PFMLIB_PMU_FL_SPEC	0x20	/* PMU provides event speculation info */
+#define PFMLIB_PMU_FL_DEPR	0x40	/* PMU model is deprecated */
 
 typedef struct {
 	int	initdone;
@@ -246,7 +252,9 @@ extern pfmlib_pmu_t amd64_fam14h_bobcat_support;
 extern pfmlib_pmu_t amd64_fam15h_interlagos_support;
 extern pfmlib_pmu_t amd64_fam15h_nb_support;
 extern pfmlib_pmu_t amd64_fam16h_support;
-extern pfmlib_pmu_t amd64_fam17h_support;
+extern pfmlib_pmu_t amd64_fam17h_deprecated_support;
+extern pfmlib_pmu_t amd64_fam17h_zen1_support;
+extern pfmlib_pmu_t amd64_fam17h_zen2_support;
 extern pfmlib_pmu_t intel_p6_support;
 extern pfmlib_pmu_t intel_ppro_support;
 extern pfmlib_pmu_t intel_pii_support;
@@ -279,6 +287,8 @@ extern pfmlib_pmu_t intel_bdw_support;
 extern pfmlib_pmu_t intel_bdw_ep_support;
 extern pfmlib_pmu_t intel_skl_support;
 extern pfmlib_pmu_t intel_skx_support;
+extern pfmlib_pmu_t intel_clx_support;
+extern pfmlib_pmu_t intel_icl_support;
 extern pfmlib_pmu_t intel_rapl_support;
 extern pfmlib_pmu_t intel_snbep_unc_cb0_support;
 extern pfmlib_pmu_t intel_snbep_unc_cb1_support;
@@ -378,6 +388,7 @@ extern pfmlib_pmu_t intel_hswep_unc_r3qpi2_support;
 extern pfmlib_pmu_t intel_hswep_unc_irp_support;
 extern pfmlib_pmu_t intel_knc_support;
 extern pfmlib_pmu_t intel_slm_support;
+extern pfmlib_pmu_t intel_tmt_support;
 extern pfmlib_pmu_t intel_knl_support;
 extern pfmlib_pmu_t intel_knl_unc_imc0_support;
 extern pfmlib_pmu_t intel_knl_unc_imc1_support;
@@ -490,6 +501,122 @@ extern pfmlib_pmu_t intel_bdx_unc_r3qpi0_support;
 extern pfmlib_pmu_t intel_bdx_unc_r3qpi1_support;
 extern pfmlib_pmu_t intel_bdx_unc_r3qpi2_support;
 extern pfmlib_pmu_t intel_bdx_unc_irp_support;
+extern pfmlib_pmu_t intel_skx_unc_cha0_support;
+extern pfmlib_pmu_t intel_skx_unc_cha1_support;
+extern pfmlib_pmu_t intel_skx_unc_cha2_support;
+extern pfmlib_pmu_t intel_skx_unc_cha3_support;
+extern pfmlib_pmu_t intel_skx_unc_cha4_support;
+extern pfmlib_pmu_t intel_skx_unc_cha5_support;
+extern pfmlib_pmu_t intel_skx_unc_cha6_support;
+extern pfmlib_pmu_t intel_skx_unc_cha7_support;
+extern pfmlib_pmu_t intel_skx_unc_cha8_support;
+extern pfmlib_pmu_t intel_skx_unc_cha9_support;
+extern pfmlib_pmu_t intel_skx_unc_cha10_support;
+extern pfmlib_pmu_t intel_skx_unc_cha11_support;
+extern pfmlib_pmu_t intel_skx_unc_cha12_support;
+extern pfmlib_pmu_t intel_skx_unc_cha13_support;
+extern pfmlib_pmu_t intel_skx_unc_cha14_support;
+extern pfmlib_pmu_t intel_skx_unc_cha15_support;
+extern pfmlib_pmu_t intel_skx_unc_cha16_support;
+extern pfmlib_pmu_t intel_skx_unc_cha17_support;
+extern pfmlib_pmu_t intel_skx_unc_cha18_support;
+extern pfmlib_pmu_t intel_skx_unc_cha19_support;
+extern pfmlib_pmu_t intel_skx_unc_cha20_support;
+extern pfmlib_pmu_t intel_skx_unc_cha21_support;
+extern pfmlib_pmu_t intel_skx_unc_cha22_support;
+extern pfmlib_pmu_t intel_skx_unc_cha23_support;
+extern pfmlib_pmu_t intel_skx_unc_cha24_support;
+extern pfmlib_pmu_t intel_skx_unc_cha25_support;
+extern pfmlib_pmu_t intel_skx_unc_cha26_support;
+extern pfmlib_pmu_t intel_skx_unc_cha27_support;
+extern pfmlib_pmu_t intel_skx_unc_iio0_support;
+extern pfmlib_pmu_t intel_skx_unc_iio1_support;
+extern pfmlib_pmu_t intel_skx_unc_iio2_support;
+extern pfmlib_pmu_t intel_skx_unc_iio3_support;
+extern pfmlib_pmu_t intel_skx_unc_iio4_support;
+extern pfmlib_pmu_t intel_skx_unc_iio5_support;
+extern pfmlib_pmu_t intel_skx_unc_imc0_support;
+extern pfmlib_pmu_t intel_skx_unc_imc1_support;
+extern pfmlib_pmu_t intel_skx_unc_imc2_support;
+extern pfmlib_pmu_t intel_skx_unc_imc3_support;
+extern pfmlib_pmu_t intel_skx_unc_imc4_support;
+extern pfmlib_pmu_t intel_skx_unc_imc5_support;
+extern pfmlib_pmu_t intel_skx_unc_pcu_support;
+extern pfmlib_pmu_t intel_skx_unc_upi0_support;
+extern pfmlib_pmu_t intel_skx_unc_upi1_support;
+extern pfmlib_pmu_t intel_skx_unc_upi2_support;
+extern pfmlib_pmu_t intel_skx_unc_m2m0_support;
+extern pfmlib_pmu_t intel_skx_unc_m2m1_support;
+extern pfmlib_pmu_t intel_skx_unc_ubo_support;
+extern pfmlib_pmu_t intel_skx_unc_m3upi0_support;
+extern pfmlib_pmu_t intel_skx_unc_m3upi1_support;
+extern pfmlib_pmu_t intel_skx_unc_m3upi2_support;
+extern pfmlib_pmu_t intel_skx_unc_irp_support;
+extern pfmlib_pmu_t intel_knm_support;
+extern pfmlib_pmu_t intel_knm_unc_imc0_support;
+extern pfmlib_pmu_t intel_knm_unc_imc1_support;
+extern pfmlib_pmu_t intel_knm_unc_imc2_support;
+extern pfmlib_pmu_t intel_knm_unc_imc3_support;
+extern pfmlib_pmu_t intel_knm_unc_imc4_support;
+extern pfmlib_pmu_t intel_knm_unc_imc5_support;
+extern pfmlib_pmu_t intel_knm_unc_imc_uclk0_support;
+extern pfmlib_pmu_t intel_knm_unc_imc_uclk1_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_uclk0_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_uclk1_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_uclk2_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_uclk3_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_uclk4_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_uclk5_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_uclk6_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_uclk7_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_eclk0_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_eclk1_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_eclk2_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_eclk3_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_eclk4_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_eclk5_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_eclk6_support;
+extern pfmlib_pmu_t intel_knm_unc_edc_eclk7_support;
+extern pfmlib_pmu_t intel_knm_unc_cha0_support;
+extern pfmlib_pmu_t intel_knm_unc_cha1_support;
+extern pfmlib_pmu_t intel_knm_unc_cha2_support;
+extern pfmlib_pmu_t intel_knm_unc_cha3_support;
+extern pfmlib_pmu_t intel_knm_unc_cha4_support;
+extern pfmlib_pmu_t intel_knm_unc_cha5_support;
+extern pfmlib_pmu_t intel_knm_unc_cha6_support;
+extern pfmlib_pmu_t intel_knm_unc_cha7_support;
+extern pfmlib_pmu_t intel_knm_unc_cha8_support;
+extern pfmlib_pmu_t intel_knm_unc_cha9_support;
+extern pfmlib_pmu_t intel_knm_unc_cha10_support;
+extern pfmlib_pmu_t intel_knm_unc_cha11_support;
+extern pfmlib_pmu_t intel_knm_unc_cha12_support;
+extern pfmlib_pmu_t intel_knm_unc_cha13_support;
+extern pfmlib_pmu_t intel_knm_unc_cha14_support;
+extern pfmlib_pmu_t intel_knm_unc_cha15_support;
+extern pfmlib_pmu_t intel_knm_unc_cha16_support;
+extern pfmlib_pmu_t intel_knm_unc_cha17_support;
+extern pfmlib_pmu_t intel_knm_unc_cha18_support;
+extern pfmlib_pmu_t intel_knm_unc_cha19_support;
+extern pfmlib_pmu_t intel_knm_unc_cha20_support;
+extern pfmlib_pmu_t intel_knm_unc_cha21_support;
+extern pfmlib_pmu_t intel_knm_unc_cha22_support;
+extern pfmlib_pmu_t intel_knm_unc_cha23_support;
+extern pfmlib_pmu_t intel_knm_unc_cha24_support;
+extern pfmlib_pmu_t intel_knm_unc_cha25_support;
+extern pfmlib_pmu_t intel_knm_unc_cha26_support;
+extern pfmlib_pmu_t intel_knm_unc_cha27_support;
+extern pfmlib_pmu_t intel_knm_unc_cha28_support;
+extern pfmlib_pmu_t intel_knm_unc_cha29_support;
+extern pfmlib_pmu_t intel_knm_unc_cha30_support;
+extern pfmlib_pmu_t intel_knm_unc_cha31_support;
+extern pfmlib_pmu_t intel_knm_unc_cha32_support;
+extern pfmlib_pmu_t intel_knm_unc_cha33_support;
+extern pfmlib_pmu_t intel_knm_unc_cha34_support;
+extern pfmlib_pmu_t intel_knm_unc_cha35_support;
+extern pfmlib_pmu_t intel_knm_unc_cha36_support;
+extern pfmlib_pmu_t intel_knm_unc_cha37_support;
+extern pfmlib_pmu_t intel_knm_unc_m2pcie_support;
+
 extern pfmlib_pmu_t intel_glm_support;
 extern pfmlib_pmu_t power4_support;
 extern pfmlib_pmu_t ppc970_support;
@@ -526,6 +653,15 @@ extern pfmlib_pmu_t arm_qcom_krait_support;
 extern pfmlib_pmu_t arm_cortex_a57_support;
 extern pfmlib_pmu_t arm_cortex_a53_support;
 extern pfmlib_pmu_t arm_xgene_support;
+
+extern pfmlib_pmu_t arm_thunderx2_support;
+extern pfmlib_pmu_t arm_thunderx2_dmc0_support;
+extern pfmlib_pmu_t arm_thunderx2_dmc1_support;
+extern pfmlib_pmu_t arm_thunderx2_llc0_support;
+extern pfmlib_pmu_t arm_thunderx2_llc1_support;
+extern pfmlib_pmu_t arm_thunderx2_ccpi0_support;
+extern pfmlib_pmu_t arm_thunderx2_ccpi1_support;
+
 extern pfmlib_pmu_t mips_74k_support;
 extern pfmlib_pmu_t s390x_cpum_cf_support;
 extern pfmlib_pmu_t s390x_cpum_sf_support;
