@@ -39,7 +39,7 @@
  *
  * @section papi_high_api High Level Functions
  * A simple interface for instrumenting end-user applications. 
- * Fully supported on both C and Fortran. 
+ * Fully supported on both C and Fortran.
  * See individual functions for details on usage.
  * 
  *	@ref high_api
@@ -61,6 +61,8 @@
  * 
  * @ref PAPIF
  *
+ * @ref PAPIF-HL
+ *
  * @section Components 
  *
  *	Components provide access to hardware information on specific subsystems.
@@ -221,7 +223,7 @@
 
 /* This is the official PAPI version */
 /* The final digit represents the patch count */
-#define PAPI_VERSION  			PAPI_VERSION_NUMBER(5,6,0,0)
+#define PAPI_VERSION  			PAPI_VERSION_NUMBER(6,0,0,1)
 #define PAPI_VER_CURRENT 		(PAPI_VERSION & 0xffff0000)
 
   /* Tests for checking event code type */
@@ -275,12 +277,14 @@ failure.
 #define PAPI_EATTR		-22    /**< Invalid or missing event attributes */
 #define PAPI_ECOUNT		-23    /**< Too many events or attributes */
 #define PAPI_ECOMBO		-24    /**< Bad combination of features */
-#define PAPI_NUM_ERRORS	 25    /**< Number of error messages specified in this API */
+#define PAPI_ECMP_DISABLED	-25    /**< Component containing event is disabled */
+#define PAPI_NUM_ERRORS	 26    /**< Number of error messages specified in this API */
 
 #define PAPI_NOT_INITED		0
 #define PAPI_LOW_LEVEL_INITED 	1       /* Low level has called library init */
 #define PAPI_HIGH_LEVEL_INITED 	2       /* High level has called library init */
 #define PAPI_THREAD_LEVEL_INITED 4      /* Threads have been inited */
+
 /** @} */
 
 /** @internal 
@@ -316,11 +320,10 @@ All of the functions in the PerfAPI should use the following set of constants.
  *	@{ */
 #define PAPI_USR1_TLS		0x0
 #define PAPI_USR2_TLS		0x1
-#define PAPI_HIGH_LEVEL_TLS     0x2
+#define PAPI_TLS_HIGH_LEVEL    0x2
 #define PAPI_NUM_TLS		0x3
 #define PAPI_TLS_USR1		PAPI_USR1_TLS
 #define PAPI_TLS_USR2		PAPI_USR2_TLS
-#define PAPI_TLS_HIGH_LEVEL     PAPI_HIGH_LEVEL_TLS
 #define PAPI_TLS_NUM		PAPI_NUM_TLS
 #define PAPI_TLS_ALL_THREADS	0x10
 /** @} */
@@ -716,7 +719,7 @@ read the documentation carefully.  */
 /** Specify the file containing user defined events. */
 typedef char* PAPI_user_defined_events_file_t;
 
-   /* The following defines and next for structures define the memory heirarchy */
+   /* The following defines and next for structures define the memory hierarchy */
    /* All sizes are in BYTES */
    /* Associativity:
 		0: Undefined;
@@ -794,7 +797,7 @@ typedef char* PAPI_user_defined_events_file_t;
       int cpu_max_mhz;              /**< Maximum supported CPU speed */
       int cpu_min_mhz;              /**< Minimum supported CPU speed */
 
-      PAPI_mh_info_t mem_hierarchy; /**< PAPI memory heirarchy description */
+      PAPI_mh_info_t mem_hierarchy; /**< PAPI memory hierarchy description */
       int virtualized;              /**< Running in virtual machine */
       char virtual_vendor_string[PAPI_MAX_STR_LEN]; 
                                     /**< Vendor for virtual machine */
@@ -1099,33 +1102,29 @@ enum {
    int   PAPI_get_component_index(const char *name); /**< Return component index for component with matching name */
    int   PAPI_disable_component(int cidx); /**< Disables a component before init */
    int	 PAPI_disable_component_by_name(const char *name ); /**< Disable, before library init, a component by name. */
+   int PAPI_num_components(void); /**< get the number of components available on the system */
 
+   int PAPI_flips_rate(int event, float *rtime, float *ptime, long long *flpins, float *mflips); /**< simplified call to get Mflips/s (floating point instruction rate), real and processor time */
+   int PAPI_flops_rate(int event, float *rtime, float *ptime, long long * flpops, float *mflops); /**< simplified call to get Mflops/s (floating point operation rate), real and processor time */
+   int PAPI_ipc(float *rtime, float *ptime, long long * ins, float *ipc); /**< gets instructions per cycle, real and processor time */
+   int PAPI_epc(int event, float *rtime, float *ptime, long long *ref, long long *core, long long *evt, float *epc); /**< gets (named) events per cycle, real and processor time, reference and core cycles */
+   int PAPI_rate_stop(); /**< stops a running event set of a rate function */
 
    /** @} */
 
 /** \internal
   @defgroup high_api  The High Level API 
 
-   The simple interface implemented by the following eight routines
-   allows the user to access and count specific hardware events from
-   both C and Fortran. It should be noted that this API can be used in
-   conjunction with the low level API. 
-	@{ */
+   The simple interface implemented by the following routines allows the user to record hardware events inside instrumented regions from both C and Fortran.
+   @{ */
 
-   int PAPI_accum_counters(long long * values, int array_len); /**< add current counts to array and reset counters */
-   int PAPI_num_counters(void); /**< get the number of hardware counters available on the system */
-   int PAPI_num_components(void); /**< get the number of components available on the system */
-   int PAPI_read_counters(long long * values, int array_len); /**< copy current counts to array and reset counters */
-   int PAPI_start_counters(int *events, int array_len); /**< start counting hardware events */
-   int PAPI_stop_counters(long long * values, int array_len); /**< stop counters and return current counts */
-   int PAPI_flips(float *rtime, float *ptime, long long * flpins, float *mflips); /**< simplified call to get Mflips/s (floating point instruction rate), real and processor time */
-   int PAPI_flops(float *rtime, float *ptime, long long * flpops, float *mflops); /**< simplified call to get Mflops/s (floating point operation rate), real and processor time */
-   int PAPI_ipc(float *rtime, float *ptime, long long * ins, float *ipc); /**< gets instructions per cycle, real and processor time */
-   int PAPI_epc(int event, float *rtime, float *ptime, long long *ref, long long *core, long long *evt, float *epc); /**< gets (named) events per cycle, real and processor time, reference and core cycles */
+   int PAPI_hl_region_begin(const char* region); /**< read performance events at the beginning of a region */
+   int PAPI_hl_read(const char* region); /**< read performance events inside of a region and store the difference to the corresponding beginning of the region */
+   int PAPI_hl_region_end(const char* region); /**< read performance events at the end of a region and store the difference to the corresponding beginning of the region */
+   int PAPI_hl_stop(); /**< stops a running high-level event set */
 /** @} */
 
 
-
 /* Backwards compatibility hacks.  Remove eventually? */
 int   PAPI_num_hwctrs(void); /**< return the number of hardware counters for the cpu. for backward compatibility. Don't use! */
 #define PAPI_COMPONENT_INDEX(a) PAPI_get_event_component(a)
