@@ -286,6 +286,10 @@ _papi_hwi_initialize_thread( ThreadInfo_t ** dest, int tid )
 		return PAPI_ENOMEM;
 	}
 
+   /* init event memory variables, used by papi_internal.c  */
+   thread->tls_papi_event_code = -1;
+   thread->tls_papi_event_code_changed = -1;
+
 	/* Call the component to fill in anything special. */
 
 	for ( i = 0; i < papi_num_components; i++ ) {
@@ -421,6 +425,11 @@ _papi_hwi_shutdown_thread( ThreadInfo_t * thread, int force_shutdown )
 	unsigned long tid;
 	int i, failure = 0;
 
+   /* Clear event memory variables */
+   thread->tls_papi_event_code = -1;
+   thread->tls_papi_event_code_changed = -1;
+
+   /* Get thread id */
 	if ( _papi_hwi_thread_id_fn )
 		tid = ( *_papi_hwi_thread_id_fn ) (  );
 	else
@@ -587,3 +596,33 @@ _papi_hwi_gather_all_thrspec_data( int tag, PAPI_all_thr_spec_t * where )
 	return ( PAPI_OK );
 
 }
+
+#if defined(__NR_gettid) && !defined(HAVE_GETTID)
+  #include <syscall.h>
+  #include <unistd.h>
+  unsigned long _papi_gettid(void)
+  {
+    return (unsigned long)(syscall(__NR_gettid));
+  } 
+#elif defined(HAVE_GETTID)
+  #include <sys/types.h>
+  unsigned long _papi_gettid(void)
+  {
+    return (unsigned long)(gettid());
+  }
+#elif defined(HAVE_SYSCALL_GETTID)
+  #include <syscall.h>
+  #include <sys/types.h>
+  unsigned long _papi_gettid(void)
+  {
+    return (unsigned long)(syscall(SYS_gettid));
+  }
+#else
+  #include <sys/types.h>
+  #include <unistd.h>
+  /* Fall-back on getpid for tid if not available. */
+  unsigned long _papi_gettid(void)
+  {
+    return (unsigned long)(getpid());
+  }
+#endif
